ensure_descriptor_compatible_with_params

Function ensure_descriptor_compatible_with_params 

fn ensure_descriptor_compatible_with_params(
    desc: &HsDesc,
    params: &NetParameters,
) -> Result<(), DescriptorErrorDetail>
Return an error if desc declares a set of parameters that is too far away from the consensus.