Data

Struct Data 

pub struct Data {
    desc: Option<HsDescForTp>,
    ipts: HashMap<RelayIdFor<IptExperienceMap>, IptExperience>,
    hsdirs: HashMap<RelayIdFor<RequeryPeriodMap>, SystemTime>,
}
Information about a hidden service, including our connection history

Fields

desc: Option<HsDescForTp>

The latest known onion service descriptor for this service.

ipts: HashMap<RelayIdFor<IptExperienceMap>, IptExperience>

Information about the latest status of trying to connect to this service through each of its introduction points.

hsdirs: HashMap<RelayIdFor<RequeryPeriodMap>, SystemTime>

Information about the requery period of each HsDir we have recently queried.

Each entry represents an HsDir that we cannot requery until its specified timestamp elapses.

Any HsDir that does not have an entry in this map can be requeried.