struct IptExperience {
duration: Duration,
outcome: Result<(), RetryTime>,
}Expand description
How things went last time we tried to use this introduction point
Neither this data structure, nor Data, is responsible for arranging that we expire this
information eventually. If we keep reconnecting to the service, we’ll retain information
about each IPT indefinitely, at least so long as they remain listed in the descriptors we
receive.
Expiry of unused data is handled by state.rs, according to last_used in ServiceState.
Choosing which IPT to prefer is done by obtaining an IptSortKey
(from this and other information).
Fields
duration: DurationHow long it took us to get whatever outcome occurred
We prefer fast successes to slow ones.
Then, we prefer failures with earlier RetryTime,
and, lastly, faster failures to slower ones.
outcome: Result<(), RetryTime>What happened and when we might try again
Note that we don’t actually enforce the RetryTime here, just sort by it
using RetryTime::loose_cmp.
We do return an error that is itself HasRetryTime and expect our callers
to honour that.