struct RelayIdForExperience(RelayId);Expand description
Lookup key for looking up and recording our IPT use experiences
Used to identify a relay when looking to see what happened last time we used it, and storing that information after we tried it.
We store the experience information under an arbitrary one of the relay’s identities,
as returned by the HasRelayIds::identities().next().
When we do lookups, we check all the relay’s identities to see if we find
anything relevant.
If relay identities permute in strange ways, whether we find our previous
knowledge about them is not particularly well defined, but that’s fine.
While this is, structurally, a relay identity, it is not suitable for other purposes.
Tuple Fields
0: RelayIdImplementations
Sourceimpl RelayIdForExperience
impl RelayIdForExperience
Sourcefn for_lookup(intro_target: &OwnedCircTarget) -> impl Iterator<Item = Self> + '_
fn for_lookup(intro_target: &OwnedCircTarget) -> impl Iterator<Item = Self> + '_
Identities to use to try to find previous experience information about this IPT
Sourcefn for_store(intro_target: &OwnedCircTarget) -> Result<Self, Bug>
fn for_store(intro_target: &OwnedCircTarget) -> Result<Self, Bug>
Identity to use to store previous experience information about this IPT