type DataHsDirs = HashMap<RelayIdFor<RequeryPeriodMap>, SystemTime>;Expand description
Part of Data that relates to our information about the HsDir requery periods
Aliased Type
struct DataHsDirs { /* private fields */ }type DataHsDirs = HashMap<RelayIdFor<RequeryPeriodMap>, SystemTime>;Part of Data that relates to our information about the HsDir requery periods
struct DataHsDirs { /* private fields */ }