type DataIpts = HashMap<RelayIdFor<IptExperienceMap>, IptExperience>;Expand description
Part of Data that relates to our information about introduction points
Aliased Type
struct DataIpts { /* private fields */ }type DataIpts = HashMap<RelayIdFor<IptExperienceMap>, IptExperience>;Part of Data that relates to our information about introduction points
struct DataIpts { /* private fields */ }