RelayIdForRequeryPeriod

Type Alias RelayIdForRequeryPeriod 

type RelayIdForRequeryPeriod = RelayIdFor<RequeryPeriodMap>;
Lookup key for looking up and recording our IPT use experiences

Aliased Type

struct RelayIdForRequeryPeriod {
    inner: RelayId,
    marker: PhantomData<RequeryPeriodMap>,
}

Fields

inner: RelayId

The relay id

marker: PhantomData<RequeryPeriodMap>

Phantom data to allow parameterizing over K

K is a marker type that represents the kind of map this key will be used in.