pub enum FailedAttemptErrorDiscriminants {
UnusableIntro,
RendezvousCircuitObtain,
RendezvousEstablishTimeout,
RendezvousEstablish,
IntroductionCircuitObtain,
IntroductionExchange,
IntroductionFailed,
IntroductionTimeout,
RendezvousCompletionTimeout,
RendezvousCompletionCircuitError,
RendezvousCompletionHandshake,
Bug,
}Expand description
Auto-generated discriminant enum variants
Variants
UnusableIntro
Introduction point unusable because it couldn’t be used as a circuit target
RendezvousCircuitObtain
Failed to obtain any circuit to use as a rendezvous circuit
RendezvousEstablishTimeout
Creating a rendezvous circuit and rendezvous point took too long
RendezvousEstablish
Failed to establish rendezvous point
IntroductionCircuitObtain
Failed to obtain circuit to introduction point
IntroductionExchange
Introduction exchange (with the introduction point) failed
IntroductionFailed
Introduction point reported error in its INTRODUCE_ACK
IntroductionTimeout
Communication with introduction point {intro_index} took too long
This might mean it took too long to establish a circuit to the IPT, or that the INTRODUCE exchange took too long.
RendezvousCompletionTimeout
It took too long for the rendezvous to be completed
This might be the fault of almost anyone. All we know is that we got
a successful INTRODUCE_ACK but the RENDEZVOUS2 never arrived.
RendezvousCompletionCircuitError
Error on rendezvous circuit when expecting rendezvous completion (RENDEZVOUS2)
RendezvousCompletionHandshake
Error processing rendezvous completion (RENDEZVOUS2)
This is might be the fault of the hidden service or the rendezvous point.
Bug
Internal error