ClientSecretKeyValues

Type Alias ClientSecretKeyValues 

type ClientSecretKeyValues = HsClientSecretKeysBuilder;
Client secret key values

Skip the whole builder pattern derivation, etc. - the types are just the same

Aliased Type

struct ClientSecretKeyValues {
    pub(crate) ks_hsc_desc_enc: Option<HsClientDescEncKeypair>,
    pub(crate) ks_hsc_intro_auth: Option<HsClientIntroAuthKeypair>,
}

Fields

ks_hsc_desc_enc: Option<HsClientDescEncKeypair>

Possibly, a key that is used to decrypt a descriptor.

ks_hsc_intro_auth: Option<HsClientIntroAuthKeypair>

Possibly, a key that is used to authenticate while introducing.