#[repr(transparent)]struct TableIndex(KeyData);Tuple Fields
0: KeyDataTrait Implementations
Sourceimpl Clone for TableIndex
impl Clone for TableIndex
Sourcefn clone(&self) -> TableIndex
fn clone(&self) -> TableIndex
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TableIndex
impl Debug for TableIndex
Sourceimpl Default for TableIndex
impl Default for TableIndex
Sourcefn default() -> TableIndex
fn default() -> TableIndex
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for TableIndex
impl<'de> Deserialize<'de> for TableIndex
Sourcefn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<KeyData> for TableIndex
impl From<KeyData> for TableIndex
Sourceimpl Hash for TableIndex
impl Hash for TableIndex
Sourceimpl Key for TableIndex
impl Key for TableIndex
Sourcefn null() -> Self
fn null() -> Self
Creates a new key that is always invalid and distinct from any non-null
key. A null key can only be created through this method (or default
initialization of keys made with
new_key_type!, which calls this
method). Read moreSourceimpl Ord for TableIndex
impl Ord for TableIndex
Sourcefn cmp(&self, other: &TableIndex) -> Ordering
fn cmp(&self, other: &TableIndex) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for TableIndex
impl PartialEq for TableIndex
Sourcefn eq(&self, other: &TableIndex) -> bool
fn eq(&self, other: &TableIndex) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for TableIndex
impl PartialOrd for TableIndex
Sourceimpl Serialize for TableIndex
impl Serialize for TableIndex
impl Copy for TableIndex
impl Eq for TableIndex
impl StructuralPartialEq for TableIndex