type DataIpts = HashMap<RelayIdForExperience, IptExperience>;Expand description
Part of Data that relates to our information about introduction points
Aliased Type
struct DataIpts { /* private fields */ }type DataIpts = HashMap<RelayIdForExperience, IptExperience>;Part of Data that relates to our information about introduction points
struct DataIpts { /* private fields */ }