type RelayIdForExperience = RelayIdFor<IptExperienceMap>;Expand description
Lookup key for looking up and recording our IPT use experiences
Aliased Type
struct RelayIdForExperience {
inner: RelayId,
marker: PhantomData<IptExperienceMap>,
}Fields
inner: RelayIdThe relay id
marker: PhantomData<IptExperienceMap>Phantom data to allow parameterizing over K
K is a marker type that represents the kind of map
this key will be used in.